Learn R Programming

quanteda.textplots (version 0.96.1)

check_font: Prepare font parameter for plotting

Description

This function prepares font parameter for use with ggplot2 and graphics APIs. No validation is performed - fonts are passed through and any invalid fonts will be handled by the graphics system.

Usage

check_font(font)

Value

character string

Arguments

font

name of a font to be used in plotting.