powered by
This function prepares font parameter for use with ggplot2 and graphics APIs. No validation is performed - fonts are passed through and any invalid fonts will be handled by the graphics system.
check_font(font)
character string
name of a font to be used in plotting.